==> org.At.tair.db_3.20.0.tar.gz: org.At.tair.db/man/org.At.tairGENENAME.Rd <==
\name{org.At.tairGENENAME}
\alias{org.At.tairGENENAME}
\title{Map between TAIR IDs and Genes}
\description{
  org.At.tairGENENAME is an R object that maps TAIR
  identifiers to the corresponding gene name.
}

\details{
  Each TAIR identifier maps to a named vector containing the gene
  name. The vector name corresponds to the TAIR identifier. If
  the gene name is unknown, the vector will contain an \code{NA}.
  
  Gene names currently include both the official (validated by a
  nomenclature committee) and preferred names (interim selected for
  display) for genes. Efforts are being made to differentiate the two
  by adding a name to the vector.

  Mappings were based on data provided by: Tair  
  https://www.arabidopsis.org/api/download-files/download?filePath=Genes/TAIR10\_genome\_release/TAIR10\_functional\_descriptions  
  With a date stamp from the source of: 2024-Sep22
  
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.At.tairGENENAME
# Get the TAIR identifiers that are mapped to a gene name
mapped_tairs <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_tairs])
if(length(xx) > 0) {
  # Get the GENENAME for the first five tairs
  xx[1:5]
  # Get the first one
  xx[[1]]
}
}
\keyword{datasets}

==> org.At.tair.db_3.21.0.tar.gz: org.At.tair.db/man/org.At.tairGENENAME.Rd <==
\name{org.At.tairGENENAME}
\alias{org.At.tairGENENAME}
\title{Map between TAIR IDs and Genes}
\description{
  org.At.tairGENENAME is an R object that maps TAIR
  identifiers to the corresponding gene name.
}

\details{
  Each TAIR identifier maps to a named vector containing the gene
  name. The vector name corresponds to the TAIR identifier. If
  the gene name is unknown, the vector will contain an \code{NA}.
  
  Gene names currently include both the official (validated by a
  nomenclature committee) and preferred names (interim selected for
  display) for genes. Efforts are being made to differentiate the two
  by adding a name to the vector.

  Mappings were based on data provided by: Tair  
  https://www.arabidopsis.org/api/download-files/download?filePath=Genes/TAIR10\_genome\_release/TAIR10\_functional\_descriptions  
  With a date stamp from the source of: 2025-Mar01
  
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.At.tairGENENAME
# Get the TAIR identifiers that are mapped to a gene name
mapped_tairs <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_tairs])
if(length(xx) > 0) {
  # Get the GENENAME for the first five tairs
  xx[1:5]
  # Get the first one
  xx[[1]]
}
}
\keyword{datasets}
